@@ -12,8 +12,9 @@ class Jsdict(object):
     def __nonzero__(self):
         return bool(self.__d)
 
-    def __setattr__(self,name,value):
-        self.__d[name] = value
+    def __setattr__(self,name,val):
+        if val is not None:
+            self.__d[name] = val
 
     def __getattr__(self,name):
         return self.__d.get(name,"")
@@ -25,7 +26,8 @@ class Jsdict(object):
         return b in self.__d
 
     def __setitem__(self,name,val):
-        self.__d[name] = val
+        if val is not None:
+            self.__d[name] = val
         
     def __delitem__(self,name):
         del self.__d[name]
@@ -48,14 +50,16 @@ class StripJsdict(object):
     def __nonzero__(self):
         return bool(self.__f)
 
-    def __setattr__(self,name,value):
-        self.__f[name] = value
+    def __setattr__(self,name,val):
+        if val is not None:
+            self.__f[name] = val
 
     def __contains__(self,b):
         return b in self.__f
 
     def __setitem__(self,name,val):
-        self.__f[name] = val
+        if val is not None:
+            self.__f[name] = val
         
     def __delitem__(self,name):
         del self.__f[name]
