@@ -2,11 +2,9 @@
 from myconf import config
 
 from os.path import join
-from hmako.lookup import TemplateLookup
-
-from mypy import render
+from mypy import mypyconfig
 #模板渲染的查找函数
-render.LOOKUP=TemplateLookup(
+mypyconfig.LOOKUP=dict(
     directories=join(config.PREFIX,'mysite/htm'),
     module_directory=join(config.PREFIX,'tmp/htm'),
     disable_unicode=True,
@@ -14,9 +12,13 @@ render.LOOKUP=TemplateLookup(
     default_filters=['str', 'h'],
     filesystem_checks=config.MAKO_FILESYSTEM_CHECK
 )
-render.FUNC_MODULE_PREFIX_LEN=len("mysite.ctrl.")
+mypyconfig.FUNC_MODULE_PREFIX_LEN=len("mysite.ctrl.")
 
 
+if config.THREAD_SAFE:
+    import threading
+    mypyconfig.LOCAL = threading.local()
+
 from mypy.route_render import _ROUTE
 from mypy.http_exc import Http404
 from mypy import render
@@ -26,7 +28,7 @@ import mysite.ctrl
 _ROUTE._install(mysite.ctrl,"mysite.ctrl")
 
 def application(request):
-    render._LOCAL.request = request
+    render.LOCAL.request = request
     uri = request.uri
     try:
         result = _ROUTE << uri.path
@@ -60,3 +62,4 @@ except ImportError:
     traceback.print_exc()
 
 from mysite.model import init_db
+
