@@ -1,7 +1,12 @@
 from init_app import application
-from mypy.wsgiserver import CherryPyWSGIServer as WsgiServer
 from myconf import config
 
+try:
+    from mypy.tornado.wsgiserver import WSGIServer as WSGIServer
+except ImportError:
+    print "import tornado.wsgiserver FAILED , USE CherryPyWSGIServer INSTEAD"
+    from mypy.wsgiserver import CherryPyWSGIServer as WSGIServer
+
 if config.SERVER_STATIC_FILE:
     from mypy import static
     from os.path import join
@@ -9,11 +14,11 @@ if config.SERVER_STATIC_FILE:
     
     STATIC_VERSION = re.compile("/\d+?~")
     STATIC_FILE = static.Cling(join(config.PREFIX,"myfile"))
-
+    STATIC_PATH = ('/css/','/js/','/pic/','/fs/','/favicon.ico','/bazs.cert','/robots.txt')
     def url_selector(func):
         def _url_selector(environ, start_response):
             path = environ['PATH_INFO']
-            for i in ('/css/','/js/','/pic/','/fs/'):
+            for i in STATIC_PATH:
                 if path.startswith(i):
                     if i in ('/css/','/js/'):
                         environ['PATH_INFO']=STATIC_VERSION.sub("/.",path)
@@ -24,10 +29,15 @@ if config.SERVER_STATIC_FILE:
 
     application = url_selector(application)
 
-def run(host='0.0.0.0',port=9888):
+def run(port=9888):
     print "server on port %s"%port
-    server = WsgiServer((host,port),application,numthreads=10)
+    server = WSGIServer(port,application)
     server.start()
 
 if __name__=="__main__":
-    run(port=9888)
+    import sys
+    if len(sys.argv)>1 and sys.argv[1].isdigit():
+        port = int(sys.argv[1])
+    else:
+        port = 9888
+    run(port=port)
